# 0.1.7
    - Fixed a bug that caused some slight numerical errors and crashing on boundary cases
    - Changed API to be consistent with the fastdtw package, so all alignment methods return (cost, path) now

# 0.1.6
    - Adding constrained DTW with a Sakoe-Chiba band

# 0.1.5
    - Fixing bug in audio alignment with time stretching

# 0.1.3
    - Adding MANIFEST.in file so that all of the source files are included when building from source

# 0.1.2
    - Adding README and finalizing structure for docs
